/*
** Module   : CalleeInfo.java
** Abstract : Interface to access useful information about the next called 
**            program/internal-entry. 
**
** Copyright (c) 2013-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 HC  20140627 Created initial version.
*/

package com.goldencode.p2j.util;


/**
 * Interface describing various data about the next called program/internal-entry.
 * The interface is for internal use only.
 */
interface CalleeInfo
{
   /** 
    * The internal entry name. In case of triggers or external programs, returns the 
    * {@link ProcedureManager#TRIGGER_PROCEDURE} and {@link ProcedureManager#EXTERNAL_PROGRAM} 
    * constants respectively.
    * 
    * @return   The internal entry name.
    */
   String getInternalEntryName();
   
   /**
    * The procedure where the internal entry was resolved.
    * 
    * @return   A valid instance.
    */
   Object getDestination();

   /** 
    * The external program name; will be non-null only when we are invoking an external 
    * program.
    * 
    * @return   A {@link String} representing the program name.
    */
   String getExternalProgramName();

   /** 
    * Flag indicating a user-defined function is called. 
    *
    * @return   A boolean flag.
    */
   boolean isFunction();
}
